/*
 * config.h
 *
 * Some configuration info
 *
 */
#ifndef __CONFIG_H__
#define __CONFIG_H__

#ifndef DEFAULT_REPOSITORY_FILE
#define DEFAULT_REPOSITORY_FILE "https://forja.rediris.es/svn/csl-qtoctave/trunk/qtoctave_pkg/octave-forge.xml"
#endif

#ifndef USER_CONFIG_FILE
#define USER_CONFIG_FILE (QDir::home().path() + "/.qtoctave/qtoctavepack.conf")
#endif

#ifndef TEMP_PATH
#define TEMP_PATH "/tmp/qopm_packages/"
#endif

#ifndef CONNECTION_TIMEOUT
#define CONNECTION_TIMEOUT 20000
#endif

#endif
